Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(595)

Unified Diff: third_party/WebKit/Source/core/loader/FrameFetchContextTest.cpp

Issue 1850123002: Rename WebFrameLoadType::ReloadFromOrigin to ReloadBypassingCache (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/loader/FrameFetchContextTest.cpp
diff --git a/third_party/WebKit/Source/core/loader/FrameFetchContextTest.cpp b/third_party/WebKit/Source/core/loader/FrameFetchContextTest.cpp
index a6e4b091d251646ae106a6d8924ad331432bee1b..f13777005ae985f9ca05dff71ca664bf5ed5c2bb 100644
--- a/third_party/WebKit/Source/core/loader/FrameFetchContextTest.cpp
+++ b/third_party/WebKit/Source/core/loader/FrameFetchContextTest.cpp
@@ -433,8 +433,8 @@ TEST_F(FrameFetchContextTest, MainResource)
document->frame()->loader().setLoadType(FrameLoadTypeReload);
EXPECT_EQ(ValidatingCacheData, childFetchContext->resourceRequestCachePolicy(request, Resource::MainResource));
- // Child frame as part of end to end reload
- document->frame()->loader().setLoadType(FrameLoadTypeReloadFromOrigin);
+ // Child frame as part of reload bypassing cache
+ document->frame()->loader().setLoadType(FrameLoadTypeReloadBypassingCache);
EXPECT_EQ(BypassingCache, childFetchContext->resourceRequestCachePolicy(request, Resource::MainResource));
}

Powered by Google App Engine
This is Rietveld 408576698